"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.XComponent = void 0;
var WebSocketConnection_1 = require("./communication/WebSocketConnection");
var log4ts_1 = require("log4ts");
var BasicLayout_1 = require("log4ts/build/layouts/BasicLayout");
var ConsoleAppender_1 = require("log4ts/build/appenders/ConsoleAppender");
var LogLevel_1 = require("log4ts/build/LogLevel");
var WebSocketBridgeCommunication_1 = require("./communication/WebSocketBridgeCommunication");
var websocket_1 = require("websocket");
var XComponent = /** @class */ (function () {
    function XComponent() {
        this.logger = log4ts_1.Logger.getLogger("XComponent");
        this.initialized = false;
    }
    XComponent.prototype.connect = function (serverUrl, errorListener, heartbeatIntervalSeconds) {
        var _this = this;
        if (heartbeatIntervalSeconds === void 0) { heartbeatIntervalSeconds = 10; }
        this.ensureInitialized();
        return new Promise(function (resolve, reject) {
            var webSocket;
            if (_this.isNodeApplication()) {
                process.env.NODE_TLS_REJECT_UNAUTHORIZED = "0";
                webSocket = new websocket_1.w3cwebsocket(serverUrl);
            }
            else {
                webSocket = new WebSocket(serverUrl);
            }
            var webSocketBridgeCommunication = new WebSocketBridgeCommunication_1.WebSocketBridgeCommunication(webSocket);
            var connection = new WebSocketConnection_1.WebSocketConnection(webSocket, webSocketBridgeCommunication);
            webSocket.onopen = (function (e) {
                connection.closedByUser = false;
                webSocketBridgeCommunication.startHeartbeat(heartbeatIntervalSeconds);
                _this.logger.info("connection started on " + serverUrl + ".");
                resolve(connection);
            }).bind(_this);
            webSocket.onerror = (function (error) {
                if (errorListener) {
                    errorListener.onError(new Error(error.toString()));
                    reject(error);
                }
                _this.logger.error("Error on " + serverUrl + ".", error);
            }).bind(_this);
            webSocket.onclose = (function (closeEvent) {
                _this.logger.info("connection on " + serverUrl + " closed.", closeEvent);
                if (!connection.closedByUser && errorListener) {
                    errorListener.onError(new Error("Unxecpected connection close on " + serverUrl));
                    reject(closeEvent);
                }
                webSocketBridgeCommunication.dispose();
                connection.dispose();
            }).bind(_this);
        });
    };
    XComponent.prototype.setLogLevel = function (logLevel) {
        this.ensureInitialized();
        this.loggerconfig.setLevel(logLevel);
    };
    XComponent.prototype.getLogLevel = function () {
        this.ensureInitialized();
        return this.loggerconfig.getLevel();
    };
    XComponent.prototype.ensureInitialized = function () {
        if (!this.initialized) {
            var consoleAppender = new ConsoleAppender_1.default();
            consoleAppender.setLayout(new BasicLayout_1.default());
            this.loggerconfig = new log4ts_1.LoggerConfig(consoleAppender, LogLevel_1.LogLevel.INFO);
            log4ts_1.Logger.setConfig(this.loggerconfig);
            this.initialized = true;
        }
    };
    XComponent.prototype.isNodeApplication = function () {
        return typeof process === "object" &&
            process + "" === "[object process]" && typeof window === "undefined";
    };
    return XComponent;
}());
exports.XComponent = XComponent;
//# sourceMappingURL=XComponent.js.map