"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebSocketBridgeCommunication = void 0;
var rxjs_1 = require("rxjs");
var operators_1 = require("rxjs/operators");
var xcWebSocketBridgeConfiguration_1 = require("../configuration/xcWebSocketBridgeConfiguration");
var xcomponentMessages_1 = require("./xcomponentMessages");
require("rxjs/add/observable/fromEvent");
var log4ts_1 = require("log4ts");
var apiConfigurationParser_1 = require("../configuration/apiConfigurationParser");
var WebSocketBridgeCommunication = /** @class */ (function () {
    function WebSocketBridgeCommunication(webSocket) {
        var _this = this;
        this.webSocket = webSocket;
        this.logger = log4ts_1.Logger.getLogger('HeartbeatManager');
        this.runnning = true;
        this.deserializer = new xcomponentMessages_1.Deserializer();
        this.serializer = new xcomponentMessages_1.Serializer();
        var thisWebSocketBridgeCommunication = this;
        this.updates$ = (0, rxjs_1.fromEvent)(this.webSocket, 'message').pipe((0, operators_1.takeWhile)(function (rawMessage) { return _this.runnning; }), (0, operators_1.map)(function (rawMessage) {
            return thisWebSocketBridgeCommunication.deserializer.deserializeWithoutTopic(rawMessage.data || rawMessage);
        }));
    }
    WebSocketBridgeCommunication.prototype.startHeartbeat = function (heartbeatIntervalSeconds) {
        var _this = this;
        var thisWebSocketBridgeCommunication = this;
        var command = xcWebSocketBridgeConfiguration_1.Commands[xcWebSocketBridgeConfiguration_1.Commands.hb];
        this.updates$
            .pipe((0, operators_1.filter)(function (data) { return data.command === command; }))
            .subscribe(function (data) {
            _this.logger.trace('Heartbeat received successfully');
        });
        var commandData = {
            Command: command,
            Data: {},
        };
        var input = thisWebSocketBridgeCommunication.serializer.convertCommandDataToWebsocketInputFormat(commandData);
        this.heartbeatTimer = setInterval(function () {
            thisWebSocketBridgeCommunication.webSocket.send(input);
            _this.logger.trace('Heartbeat sent');
        }, heartbeatIntervalSeconds * 1000);
    };
    WebSocketBridgeCommunication.prototype.getCompositionModel = function (apiName) {
        var _this = this;
        var thisWebSocketBridgeCommunication = this;
        var command = xcWebSocketBridgeConfiguration_1.Commands[xcWebSocketBridgeConfiguration_1.Commands.getModel];
        var promise = this.updates$
            .pipe((0, operators_1.filter)(function (data) { return data.command === command; }), (0, operators_1.first)(), (0, operators_1.map)(function (data) {
            return thisWebSocketBridgeCommunication.deserializer.getJsonDataFromGetModelRequest(data.stringData);
        }))
            .toPromise()
            .then(function (compositionModel) {
            if (!compositionModel) {
                var errorMessage = 'Model ' + apiName + ' not found';
                _this.logger.error(errorMessage);
                throw new Error(errorMessage);
            }
            _this.logger.info('Model ' + apiName + ' received successfully');
            return compositionModel;
        });
        var commandData = {
            Command: command,
            Data: { Name: apiName },
        };
        var input = thisWebSocketBridgeCommunication.serializer.convertCommandDataToWebsocketInputFormat(commandData);
        this.webSocket.send(input);
        return promise;
    };
    WebSocketBridgeCommunication.prototype.getXcApiList = function () {
        var _this = this;
        var thisWebSocketBridgeCommunication = this;
        var command = xcWebSocketBridgeConfiguration_1.Commands[xcWebSocketBridgeConfiguration_1.Commands.getXcApiList];
        var promise = this.updates$
            .pipe((0, operators_1.filter)(function (data) { return data.command === command; }), (0, operators_1.first)(), (0, operators_1.map)(function (data) {
            _this.logger.info('ApiList received successfully : ' + JSON.stringify(data));
            return thisWebSocketBridgeCommunication.deserializer.getJsonDataFromGetXcApiListRequest(data.stringData);
        }))
            .toPromise();
        var commandData = {
            Command: command,
            Data: {},
        };
        this.webSocket.send(thisWebSocketBridgeCommunication.serializer.convertCommandDataToWebsocketInputFormat(commandData));
        return promise;
    };
    WebSocketBridgeCommunication.prototype.getXcApiConfiguration = function (apiName) {
        var _this = this;
        var thisWebSocketBridgeCommunication = this;
        var command = xcWebSocketBridgeConfiguration_1.Commands[xcWebSocketBridgeConfiguration_1.Commands.getXcApi];
        var promise = this.updates$
            .pipe((0, operators_1.filter)(function (data) { return data.command === command; }), (0, operators_1.first)(), (0, operators_1.map)(function (data) {
            _this.logger.info(apiName + ' ' + 'received successfully');
            return thisWebSocketBridgeCommunication.deserializer.getJsonDataFromXcApiRequest(data.stringData);
        }))
            .toPromise()
            .then(function (xcApi) {
            if (!xcApi) {
                var errorMessage = "Unknown Api: ".concat(apiName);
                _this.logger.error(errorMessage);
                throw new Error(errorMessage);
            }
            var parser = new apiConfigurationParser_1.DefaultApiConfigurationParser();
            return parser.parse(xcApi);
        });
        var commandData = {
            Command: command,
            Data: { Name: apiName },
        };
        this.webSocket.send(thisWebSocketBridgeCommunication.serializer.convertCommandDataToWebsocketInputFormat(commandData));
        return promise;
    };
    WebSocketBridgeCommunication.prototype.dispose = function () {
        clearInterval(this.heartbeatTimer);
        this.runnning = false;
    };
    return WebSocketBridgeCommunication;
}());
exports.WebSocketBridgeCommunication = WebSocketBridgeCommunication;
//# sourceMappingURL=WebSocketBridgeCommunication.js.map