"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebSocketSession = void 0;
var WebSocketPublisher_1 = require("./WebSocketPublisher");
var WebSocketSubscriber_1 = require("./WebSocketSubscriber");
var PrivateTopics_1 = require("../interfaces/PrivateTopics");
var WebSocketSession = /** @class */ (function () {
    function WebSocketSession(webSocketWrapper, configuration, sessionData) {
        this.subscriber = new WebSocketSubscriber_1.WebSocketSubscriber(webSocketWrapper, configuration);
        this.privateTopics = new PrivateTopics_1.PrivateTopics(this.subscriber);
        this.publisher = new WebSocketPublisher_1.WebSocketPublisher(webSocketWrapper, configuration, this.privateTopics, sessionData);
        this.subscriber.setStateMachineRefSendPublisher(this.publisher);
    }
    WebSocketSession.prototype.send = function (componentName, stateMachineName, messageType, jsonMessage, visibilityPrivate, specifiedPrivateTopic) {
        if (visibilityPrivate === void 0) { visibilityPrivate = false; }
        this.publisher.send(componentName, stateMachineName, messageType, jsonMessage, visibilityPrivate, specifiedPrivateTopic);
    };
    WebSocketSession.prototype.canSend = function (componentName, stateMachineName, messageType) {
        return this.publisher.canSend(componentName, stateMachineName, messageType);
    };
    WebSocketSession.prototype.getSnapshot = function (componentName, stateMachineName) {
        return this.subscriber.getSnapshot(componentName, stateMachineName, this.privateTopics);
    };
    WebSocketSession.prototype.getStateMachineUpdates = function (componentName, stateMachineName) {
        return this.subscriber.getStateMachineUpdates(componentName, stateMachineName);
    };
    WebSocketSession.prototype.subscribe = function (componentName, stateMachineName, stateMachineUpdateListener) {
        this.subscriber.subscribe(componentName, stateMachineName, stateMachineUpdateListener);
    };
    WebSocketSession.prototype.unsubscribe = function (componentName, stateMachineName) {
        this.subscriber.unsubscribe(componentName, stateMachineName);
        throw new Error('Method not implemented.');
    };
    WebSocketSession.prototype.canSubscribe = function (componentName, stateMachineName) {
        return this.subscriber.canSubscribe(componentName, stateMachineName);
    };
    WebSocketSession.prototype.dispose = function () {
        this.privateTopics.dispose();
    };
    return WebSocketSession;
}());
exports.WebSocketSession = WebSocketSession;
//# sourceMappingURL=WebSocketSession.js.map