"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Deserializer = exports.Serializer = exports.getHeaderWithIncomingType = exports.fatalErrorState = void 0;
var log4ts_1 = require("log4ts");
var pako = require("pako");
var atob = require("atob");
exports.fatalErrorState = 'FatalError';
var getHeaderWithIncomingType = function () {
    return {
        IncomingEventType: 0,
    };
};
exports.getHeaderWithIncomingType = getHeaderWithIncomingType;
var Serializer = /** @class */ (function () {
    function Serializer() {
        this.logger = log4ts_1.Logger.getLogger('Serializer');
    }
    Serializer.prototype.convertToWebsocketInputFormat = function (data) {
        var input = "".concat(data.RoutingKey, " ").concat(data.ComponentCode, " ").concat(JSON.stringify(data.Event));
        this.logger.debug('Message send : ', input);
        return input;
    };
    Serializer.prototype.convertCommandDataToWebsocketInputFormat = function (commandData) {
        var input = "".concat(commandData.Command, " ").concat(JSON.stringify(commandData.Data));
        this.logger.debug('Message send : ', input);
        return input;
    };
    return Serializer;
}());
exports.Serializer = Serializer;
var Deserializer = /** @class */ (function () {
    function Deserializer() {
    }
    Deserializer.prototype.getJsonDataFromGetModelRequest = function (stringData) {
        var jsonData = this.getJsonData(stringData);
        var components = new Array();
        for (var i = 0; i < jsonData.ModelContent.Components.length; i++) {
            var component = jsonData.ModelContent.Components[i];
            if (component.Model) {
                components.push({
                    name: component.Name,
                    model: this.decodeServerMessage(component.Model),
                    graphical: this.decodeServerMessage(component.Graphical),
                });
            }
        }
        if (jsonData.ModelContent.Composition) {
            return {
                projectName: jsonData.ModelContent.ProjectName,
                components: components,
                composition: this.decodeServerMessage(jsonData.ModelContent.Composition),
            };
        }
        return undefined;
    };
    Deserializer.prototype.decodeServerMessage = function (b64Data) {
        if (b64Data === undefined) {
            return undefined;
        }
        var charData = atob(b64Data)
            .split('')
            .map(function (x) {
            return x.charCodeAt(0);
        });
        var binData = new Uint8Array(charData);
        var data = pako.inflate(binData).filter(function (x) {
            return x !== 0;
        });
        var finalData = new Uint16Array(data);
        var strData = '';
        for (var i = 0; i < finalData.length; i++) {
            strData += String.fromCharCode(finalData[i]);
        }
        return strData;
    };
    Deserializer.prototype.getJsonDataFromXcApiRequest = function (data) {
        var jsonData = this.getJsonData(data);
        return jsonData.ApiFound ? this.decodeServerMessage(jsonData.Content) : undefined;
    };
    Deserializer.prototype.getJsonDataFromGetXcApiListRequest = function (data) {
        var jsonData = this.getJsonData(data);
        return jsonData.Apis.$values;
    };
    // tslint:disable-next-line:no-any
    Deserializer.prototype.getJsonData = function (data) {
        return JSON.parse(data.substring(data.indexOf('{'), data.lastIndexOf('}') + 1));
    };
    Deserializer.prototype.getPosition = function (str, subString, index) {
        return str.split(subString, index).join(subString).length;
    };
    Deserializer.prototype.deserialize = function (data) {
        var s = data.split(' ');
        var command = s.splice(0, 1)[0];
        var topic = s.splice(0, 1)[0];
        var stringData = s.join(' ');
        return {
            command: command,
            topic: topic,
            stringData: stringData,
        };
    };
    Deserializer.prototype.deserializeWithoutTopic = function (data) {
        var s = data.split(' ');
        var command = s.splice(0, 1)[0];
        var stringData = s.join(' ');
        return {
            command: command,
            topic: undefined,
            stringData: stringData,
        };
    };
    return Deserializer;
}());
exports.Deserializer = Deserializer;
//# sourceMappingURL=xcomponentMessages.js.map